@@ -7,7 +7,7 @@ master_doc = 'index'
 project = u'dynpool'
 copyright = u'2014, Gustavo Picon'
 version = '1.0'
-release = '1.0'
+release = '1.0.1'
 exclude_trees = ['_build']
 pygments_style = 'sphinx'
 html_theme = 'default'
